@@ -4,7 +4,7 @@ use warnings;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000077';
+our $VERSION = '0.000121';
 
 use Test2::Util::HashBase qw/item/;
 
@@ -14,7 +14,7 @@ use Scalar::Util qw/reftype blessed/;
 sub init {
     my $self = shift;
     croak "'item' is a required attribute"
-        unless $self->{+ITEM};
+        unless defined $self->{+ITEM};
 
     $self->SUPER::init();
 }
@@ -30,7 +30,7 @@ sub verify {
     return 0 unless $exists;
     return 0 unless defined $got;
     return 0 unless ref($got);
-    return 0 unless reftype($got) eq 'SCALAR';
+    return 0 unless reftype($got) eq 'SCALAR' || reftype($got) eq 'VSTRING';
     return 1;
 }
 
@@ -81,7 +81,7 @@ This is used in deep comparisons to represent a scalar reference.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
@@ -101,7 +101,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
